media
=====

.. automodule:: deltona.media
   :exclude-members: supported_audio_input_formats
   :members:
   :show-inheritance:

.. autofunction:: supported_audio_input_formats(input_device: str, formats: Sequence[str] = ..., rates: Sequence[int] = ...) -> tuple[tuple[str, str], ...]

.. _ffmpeg crop filter: https://ffmpeg.org/ffmpeg-filters.html#crop
.. _ffmpeg setpts filter: https://ffmpeg.org/ffmpeg-filters.html#setpts_002c-asetpts
.. _strptime() Format Codes: https://docs.python.org/3/library/datetime.html#strftime-and-strptime-format-codes
